pub trait ConnectionAccess:
Clone
+ Debug
+ Eq
+ PartialEq
+ Serialize
+ 'static {
type Kafka: Clone + Debug + Eq + PartialEq + Hash + Serialize + for<'a> Deserialize<'a> + AlterCompatible;
type Pg: Clone + Debug + Eq + PartialEq + Hash + Serialize + for<'a> Deserialize<'a> + AlterCompatible;
type Aws: Clone + Debug + Eq + PartialEq + Hash + Serialize + for<'a> Deserialize<'a> + AlterCompatible;
type Ssh: Clone + Debug + Eq + PartialEq + Hash + Serialize + for<'a> Deserialize<'a> + AlterCompatible;
type Csr: Clone + Debug + Eq + PartialEq + Hash + Serialize + for<'a> Deserialize<'a> + AlterCompatible;
type MySql: Clone + Debug + Eq + PartialEq + Hash + Serialize + for<'a> Deserialize<'a> + AlterCompatible;
type SqlServer: Clone + Debug + Eq + PartialEq + Hash + Serialize + for<'a> Deserialize<'a> + AlterCompatible;
type IcebergCatalog: Clone + Debug + Eq + PartialEq + Hash + Serialize + for<'a> Deserialize<'a> + AlterCompatible;
}Expand description
Expresses how a struct/enum can access details about any connections it uses. Meant to be used as a type constraint on structs that use connections.
Required Associated Types
type Kafka: Clone + Debug + Eq + PartialEq + Hash + Serialize + for<'a> Deserialize<'a> + AlterCompatible
type Pg: Clone + Debug + Eq + PartialEq + Hash + Serialize + for<'a> Deserialize<'a> + AlterCompatible
type Aws: Clone + Debug + Eq + PartialEq + Hash + Serialize + for<'a> Deserialize<'a> + AlterCompatible
type Ssh: Clone + Debug + Eq + PartialEq + Hash + Serialize + for<'a> Deserialize<'a> + AlterCompatible
type Csr: Clone + Debug + Eq + PartialEq + Hash + Serialize + for<'a> Deserialize<'a> + AlterCompatible
type MySql: Clone + Debug + Eq + PartialEq + Hash + Serialize + for<'a> Deserialize<'a> + AlterCompatible
type SqlServer: Clone + Debug + Eq + PartialEq + Hash + Serialize + for<'a> Deserialize<'a> + AlterCompatible
type IcebergCatalog: Clone + Debug + Eq + PartialEq + Hash + Serialize + for<'a> Deserialize<'a> + AlterCompatible
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.